@@ -16,13 +16,6 @@ def import_processors():
 
 def find_all_processors():
     import_processors()
-    results = inspect.getmembers(import_processors())
-
-    result = []
-    for cls in results:
-        try:
-            assert cls[1].is_flow_processor
-            result.append(cls[1])
-        except:
-            pass
+    inspect.getmembers(import_processors())
+    result = [cls for cls in BaseFlowProcessor.__subclasses__()]
     return result
